/**
 * ITaskProviderCallback.java
 *
 * Licensed Materials - Property of IBM
 * Rational ClearCase
 * (C) Copyright IBM Corp. 2011, 2014.  All Rights Reserved
 * US Government Users Restricted Rights -
 * Use, duplication or disclosure restricted by GSA ADP Schedule Contract with IBM Corp
 *
 * The source code for this program is not published or otherwise
 * divested of its trade secrets, irrespective of what has been
 * deposited with the U.S. Copyright Office.
 */
package com.ibm.rational.team.client.ui.external.extensions.interfaces;

import java.util.List;

public interface ITaskProviderCallback {

	/**
	 * Called by the Task Provider to add task associations
	 * 
	 * @param objects - the objects to add task associations to
	 * 	The String representing an object must be of the format provided by CCObjectFactory.makeUriString()
	 * @param taskUri - the uri's of the "tasks" to associate with the objects 
	 * 	
	 */
	public void addTaskAssociations(List<String> objects, List<String> taskUri);
	
	/**
	 * Called by the Task Provider to remove task associations
	 * 
	 * @param objects - the objects to remove task associations from
	 * 	The String representing an object must be of the format provided by CCObjectFactory.makeUriString()	 * 
	 * @param taskUri - the uri's of the "tasks" to remove the objects' associations with 
	 */
	public void removeTaskAssociations(List<String> objects, List<String> taskUri);
	
	/**
	 * This is a proxy class for {@link com.ibm.rational.team.client.ui.external.extensions.interfaces.ITaskProviderCallback }
	 * interface. The ClearTeam Explorer provides the call back object through {@link com.ibm.rational.team.client.ui.external.extensions.interfaces.IAdvancedTaskProvider#registerCallback(com.ibm.rational.team.client.ui.external.extensions.interfaces.ITaskProviderCallback) }
	 * API and RTC-side will call appropriate APIs when it creates/deletes links.
	 *
	 */
	public List<String> getTaskProviderNames(List<String> objects);
}
